@@ -41,16 +41,16 @@ plot_columns <- function(dt, by_column = NULL){
 #' columns are plotted in box plots. If 'by_column' is provided,
 #' these plots will be grouped by the values of that column
 #'
-#' @param dt Table to be plotted.
-#' @param by_column Name of the column to use as groups for all the other plots
-#' @param filename Name of the output file.
-#' @param output_format The format of the R Markdown file. Default is prettydoc. Currently supported: 'prettydoc', 'ioslides', 'tufte', 'flexdashboard', 'slidy_presentation', 'html_document' and 'html_notebook'.
-#' @param author Author of the report.
+#' @param dt Table to be studied.
+#' @param by_column Name of the column to use as groups for all the other plots. Default is NULL.
+#' @param filename Name of the output file. If not supplied, a generic name will be created.
+#' @param output_format The format of the R Markdown output. Default is 'rmdformats'.
+#' @param author Author of the report. Default is NULL.
 #' @param horizontal_bars Plot bars for categorical variables horizontally. Default is FALSE
 #' @param sort_bars_value Sort the bars by value. Default is FALSE.
 #' @param sort_bars_decreasingly Sort the bars decreasingly. Default is TRUE.
+#' @param rmdformats_theme The theme to be used for [rmdformats](https://github.com/juba/rmdformats) outputs. Default is "downcute", and possible values are "downcute", "robobook", "material", "readthedown", "html_clean", "html_docco".
 #' @param prettydoc_theme Name of the theme used on prettydoc. Default is leonids.
-#' @param highlight Rmarkdown highlight theming. Default is github highlighting.
 #' @param number_sections Whether or not to number the sections and subsections fo the report.
 #' @param table_of_content Whether or not to include a table fo content at the beginning of the report.
 #' @param table_of_content_depth The depth of sections and subsections to be displayed on the table of content.
@@ -58,7 +58,7 @@ plot_columns <- function(dt, by_column = NULL){
 #' @param fig_height Set the global figure height or the rmarkdown file.
 #' @param directory The directory in which to render the .html report
 #' @param keep_rmd Whether or not to keep the .Rmd file. Default is false.
-#' @param render_html Whether or not to render the report as an interactive hmtl file.
+#' @param render_reports Whether or not to render the reports. Default is TRUE. Set render_reports = FALSE and keep_rmd = TRUE to only build the R Markdown files
 #'
 #' @return Creates an HTML file with a plot for each column on the given table: a box plot for each numerical variable, and a bar plot for each categorical variable.
 #' @export
@@ -73,31 +73,33 @@ plot_columns <- function(dt, by_column = NULL){
 report_columns <- function(dt,
                            by_column = NULL,
                            filename = NULL,
-                           output_format = 'prettydoc',
-                           author = 'chronicle user',
+                           output_format = 'rmdformats',
+                           author = NULL,
                            horizontal_bars = FALSE,
                            sort_bars_value = FALSE,
                            sort_bars_decreasingly = TRUE,
+                           rmdformats_theme = 'downcute',
                            prettydoc_theme = 'leonids',
-                           highlight = 'github',
                            number_sections = TRUE,
                            table_of_content = TRUE,
                            table_of_content_depth = 1,
-                           fig_width = 11,
-                           fig_height = 5,
+                           fig_width = 9,
+                           fig_height = 4,
                            directory = getwd(),
                            keep_rmd = FALSE,
-                           render_html = TRUE){
+                           render_reports = TRUE){
 
   # create report title
   dt_name <- deparse(substitute(dt))
-  title <- paste(dt_name, 'Variable Analysis', if(!is.null(by_column)){paste('by', by_column)})
+  title <- paste(dt_name,
+                 'Variable Analysis',
+                 if(!is.null(by_column)){paste('by', by_column)})
 
   # create filename
   if(is.null(filename)){
-    filename <- gsub('[^[:alnum:][:space:]]',
-                     '',
-                     dt_name) %>%
+    filename <- gsub(pattern = '[^[:alnum:][:space:]]',
+                     replacement = '',
+                     x = dt_name) %>%
       paste0('_column_analysis')
   }
 
@@ -105,11 +107,11 @@ report_columns <- function(dt,
   nums <- dt %>% purrr::keep(is.numeric) %>% colnames()
   nums %<>% purrr::set_names(nums)
   if(length(nums) > 0){
-    num_plots <- nums %>% purrr::map(~add_boxplot(dt = dt_name,
+    num_plots <- nums %>% purrr::map(~chronicle::add_raincloud(dt = dt_name,
                                                   value = .x,
                                                   groups = by_column,
-                                                  title_level = 1,
-                                                  jitter = TRUE))
+                                                  title_level = 2,
+                                                  raincloud_title = .x))
   }else{
     num_plots <- NULL
   }
@@ -118,13 +120,14 @@ report_columns <- function(dt,
   cats <- dt %>% purrr::discard(is.numeric) %>% colnames()
   cats %<>% purrr::set_names(cats)
   if(length(cats) > 0){
-    cat_plots <- cats %>% purrr::map(~add_barplot(dt = dt_name,
+    cat_plots <- cats %>% purrr::map(~chronicle::add_barplot(dt = dt_name,
                                                   bars = .x,
                                                   break_bars_by = by_column,
                                                   horizontal = horizontal_bars,
                                                   sort_by_value = sort_bars_value,
                                                   sort_decreasing = sort_bars_decreasingly,
-                                                  title_level = 1))
+                                                  title_level = 2,
+                                                  barplot_title = .x))
   }else{
     cat_plots <- NULL
   }
@@ -142,18 +145,28 @@ report_columns <- function(dt,
       purrr::reduce(paste, sep = '\n')
   }
 
-  if(!render_html){
+  if(!render_reports){
     return((plot_sections))
   }
 
+  # add skimr::skim
+  plot_sections <- paste(add_code(code = paste0('skimr::skim(', dt_name, ')'),
+                                  code_title = 'Dataset overview',
+                                  echo = FALSE),
+                         add_title(title = 'Column Plots',
+                                   title_level = 1),
+                         plot_sections,
+                         sep = '\n')
+
+
   # render report
   chronicle::render_report(report = plot_sections,
                            title = title,
                            author = author,
                            filename = filename,
                            output_format = output_format,
+                           rmdformats_theme = rmdformats_theme,
                            prettydoc_theme = prettydoc_theme,
-                           highlight = highlight,
                            number_sections = number_sections,
                            table_of_content = table_of_content,
                            table_of_content_depth = table_of_content_depth,
@@ -161,6 +174,6 @@ report_columns <- function(dt,
                            fig_height = fig_height,
                            directory = directory,
                            keep_rmd = keep_rmd,
-                           render_html = render_html)
+                           render_reports = render_reports)
 
 }
