@@ -6,12 +6,14 @@
 #' @param groups Name of the column containing the different groups.
 #' @param faceted If TRUE (default), each group will be plotted separately.
 #' @param scales From ggplot2::facet_wrap: Should scales be 'fixed', 'free', or free in one dimension ('free_x', 'free_y'). Default is 'fixed'.
-#' @param smooth_trend If TRUE, adds a ggplot2::geom_smooth() line to the plot.
+#' @param show_trend If TRUE, adds a ggplot2::geom_smooth() line to the plot.
+#' @param trend_method The method ggplot2::geom_smooth will use. Default is 'loess', which is a local polynomial regression fit
 #' @param ggtheme ggplot2 theme function to apply. Default is ggplot2::theme_minimal.
 #' @param x_axis_label Label for the x axis.
 #' @param y_axis_label Label for the y axis.
 #' @param plot_palette Character vector of hex codes specifying the colors to use on the plot.
 #' @param plot_palette_generator Palette from the viridis package, used in case plot_palette is unspecified or insufficient for the number of colors required.
+#' @param static If TRUE, the output will be static ggplot chart instead of an interactive ggplotly chart. Default is FALSE.
 #'
 #' @export
 #' @return A plotly-ized version of a grouped ggplot scatter plot.
@@ -37,12 +39,20 @@ make_scatterplot <- function(dt,
                           groups = NULL,
                           faceted = FALSE,
                           scales = 'fixed',
-                          smooth_trend = FALSE,
+                          show_trend = FALSE,
+                          trend_method = 'loess',
                           ggtheme = 'minimal',
                           x_axis_label = NULL,
                           y_axis_label = NULL,
                           plot_palette = NULL,
-                          plot_palette_generator = 'plasma'){
+                          plot_palette_generator = 'plasma',
+                          static = FALSE){
+
+
+  dt_cols <- c(x, y, groups)
+  if(any((!dt_cols %in% colnames(dt)))){
+    stop(paste(setdiff(dt_cols, colnames(dt)), collapse = ', '), ' not found on dt.')
+  }
 
   # check how many colors are needed for plotting
   plot_palette_length <- ifelse(test = is.null(groups),
@@ -85,7 +95,8 @@ make_scatterplot <- function(dt,
   }
 
   # create the plot structure depending of the group
-  if(is.null(groups)){
+  null_groups <- is.null(groups)
+  if(null_groups){
     # make a dummy group variable
     groups <- 'groups'
     dt$groups <- 'A'
@@ -94,14 +105,16 @@ make_scatterplot <- function(dt,
                               ggplot2::aes(x = .data[[x]],
                                            y = .data[[y]],
                                            color = .data[[groups]])) +
-    ggplot2::geom_point() +
+    ggplot2::geom_point(alpha = .85) +
     ggtheme() +
+    ggplot2::theme(panel.background = ggplot2::element_rect(fill = "transparent", colour = NA),
+                   plot.background =  ggplot2::element_rect(fill = "transparent", colour = NA)) +
     ggplot2::scale_y_continuous(labels = scales::number_format(accuracy = 0.01,
                                                                decimal.mark = '.',
                                                                big.mark = ',')) +
     ggplot2::scale_color_manual(values = plot_palette)
 
-  if(is.null(groups)){
+  if(null_groups){
     scatterplot <- scatterplot + ggplot2::theme(legend.position = 'none')
   }
 
@@ -128,11 +141,14 @@ make_scatterplot <- function(dt,
   }
 
   # smooth trend line
-  if(as.logical(smooth_trend)){
-    scatterplot <- scatterplot +ggplot2::geom_smooth()
+  if(as.logical(show_trend)){
+    scatterplot <- scatterplot + ggplot2::geom_smooth(formula = y~x, method = trend_method)
+  }
+
+  if(!static){
+    scatterplot <- plotly::ggplotly(scatterplot,  tooltip = c('x', 'y', if(groups != 'groups'){'color'}))
   }
 
-  scatterplot <- plotly::ggplotly(scatterplot,  tooltip = c('x', 'y', if(groups != 'groups'){'color'}))
   return(scatterplot)
 }
 
@@ -145,7 +161,8 @@ make_scatterplot <- function(dt,
 #' @param groups Name of the column containing the different groups.
 #' @param faceted If TRUE (default), each group will be plotted separately.
 #' @param scales From ggplot2::facet_wrap: Should scales be 'fixed', 'free', or free in one dimension ('free_x', 'free_y'). Default is 'fixed'.
-#' @param smooth_trend If TRUE, adds a ggplot2::geom_smooth() line to the plot. Default is FALSE.
+#' @param show_trend If TRUE, adds a ggplot2::geom_smooth() line to the plot. Default is FALSE.
+#' @param trend_method The method ggplot2::geom_smooth will use. Default is 'loess', which is a local polynomial regression fit
 #' @param ggtheme ggplot2 theme function to apply. Default is ggplot2::theme_minimal.
 #' @param x_axis_label Label for the x axis.
 #' @param y_axis_label Label for the y axis.
@@ -163,7 +180,7 @@ make_scatterplot <- function(dt,
 #' @export
 #'
 #' @examples
-#' html_report <- add_scatterplot(report = new_report(),
+#' html_report <- add_scatterplot(report = "",
 #'                             dt = ggplot2::mpg,
 #'                             x = 'hwy',
 #'                             y = 'cty',
@@ -177,7 +194,8 @@ add_scatterplot <- function(report = '',
                             groups = NULL,
                             faceted = NULL,
                             scales = NULL,
-                            smooth_trend = NULL,
+                            show_trend = NULL,
+                            trend_method = NULL,
                             ggtheme = NULL,
                             x_axis_label = NULL,
                             y_axis_label = NULL,
@@ -191,12 +209,18 @@ add_scatterplot <- function(report = '',
                             fig_width = NULL,
                             fig_height = NULL){
 
+  dt_cols <- c(x, y, groups)
+  if(any((!dt_cols %in% colnames(dt)))){
+    stop(paste(setdiff(dt_cols, colnames(dt)), collapse = ', '), ' not found on dt.')
+  }
+
   params <- list(x = x,
                  y = y,
                  groups = groups,
                  faceted = faceted,
                  scales = scales,
-                 smooth_trend = smooth_trend,
+                 show_trend = show_trend,
+                 trend_method = trend_method,
                  ggtheme = ggtheme,
                  x_axis_label = x_axis_label,
                  y_axis_label = y_axis_label,
